Crate shrimple_telegram

Crate shrimple_telegram 

A library for running a Telegram bot.

Work in progress.

Modules

methods
types

Structs

Bot
A high-level representation of the connection to Telegram Bot API.
BotBuilder
A builder for the Bot that allows for customising the API URL & the HTTPS client config used for connecting to the API endpoint.

Enums

Error
An error that can occur while sending a request to Telegram Bot API

Constants

MAX_MSG_LEN

Traits

Request

Type Aliases

Result