pub struct SendDocument<'src> {
pub chat_id: ChatId,
pub document: InputFile<'src>,
pub caption: Cow<'src, str>,
pub parse_mode: Option<ParseMode>,
pub reply_to_message_id: Option<MessageId>,
pub reply_markup: ReplyMarkup<'src>,
/* private fields */
}Expand description
Warning
If the input document is a stream, attempting to clone this object or turn it into a future
via crate::Request::to_future will result in a panic
Fields
chat_id: ChatIddocument: InputFile<'src>caption: Cow<'src, str>parse_mode: Option<ParseMode>reply_to_message_id: Option<MessageId>reply_markup: ReplyMarkup<'src>Implementations
Sourceimpl<'src> SendDocument<'src>
impl<'src> SendDocument<'src>
pub fn chat_id(self, chat_id: ChatId) -> Self
pub fn document(self, document: InputFile<'src>) -> Self
pub fn caption(self, caption: impl Into<Cow<'src, str>>) -> Self
pub fn parse_mode(self, parse_mode: impl Into<Option<ParseMode>>) -> Self
pub fn reply_to_message_id( self, reply_to_message_id: impl Into<Option<MessageId>>, ) -> Self
pub fn reply_markup(self, reply_markup: impl Into<ReplyMarkup<'src>>) -> Self