A library for running a Telegram bot.
Work in progress.
Modules
Structs
- Bot
- A high-level representation of the connection to Telegram Bot API.
- BotBuilder
- A builder for the
Botthat allows for customising the API URL & the HTTPS client config used for connecting to the API endpoint.
Enums
- Error
- An error that can occur while sending a request to Telegram Bot API